@@ -105,6 +105,8 @@ class Drawing:
     lineJoin = gstateDelegateMethod()
     lineDash = gstateDelegateMethod()
     miterLimit = gstateDelegateMethod()
+    linearGradient = gstateDelegateMethod()
+    radialGradient = gstateDelegateMethod()
     font = gstateDelegateMethod()
     fontSize = gstateDelegateMethod()
     openTypeFeatures = gstateDelegateMethod()
