@@ -1,3 +1,4 @@
+import logging
 import os
 import skia
 from .errors import DrawbotError
@@ -31,16 +32,16 @@ class GraphicsStateMixin:
     def fill(self, *args):
         color = _colorArgs(args)
         if color is None:
-            self.fillPaint = self.fillPaint.copy(somethingToDraw=False)
+            self.fillPaint = self.fillPaint.copy(somethingToDraw=False, shader=None)
         else:
-            self.fillPaint = self.fillPaint.copy(color=color, somethingToDraw=True)
+            self.fillPaint = self.fillPaint.copy(color=color, somethingToDraw=True, shader=None)
 
     def stroke(self, *args):
         color = _colorArgs(args)
         if color is None:
-            self.strokePaint = self.strokePaint.copy(somethingToDraw=False)
+            self.strokePaint = self.strokePaint.copy(somethingToDraw=False, shader=None)
         else:
-            self.strokePaint = self.strokePaint.copy(color=color, somethingToDraw=True)
+            self.strokePaint = self.strokePaint.copy(color=color, somethingToDraw=True, shader=None)
 
     def blendMode(self, blendMode):
         if blendMode not in _blendModes:
@@ -74,6 +75,44 @@ class GraphicsStateMixin:
     def miterLimit(self, miterLimit):
         self.strokePaint = self.strokePaint.copy(miterLimit=miterLimit)
 
+    def linearGradient(self, startPoint, endPoint, colors, locations=None):
+        # MakeLinear(
+        #   points: List[skia.Point],
+        #   colors: List[int],
+        #   positions: object = None,
+        #   mode: skia.TileMode = TileMode.kClamp,
+        #   flags: int = 0,
+        #   localMatrix: skia.Matrix = None) -> skia.Shader
+        colors = [_colorTupleToInt(_colorArgs(c)) for c in colors]
+        shader = skia.GradientShader.MakeLinear(
+            points=[startPoint, endPoint],
+            colors=colors,
+            positions=locations,
+        )
+        self.fillPaint = self.fillPaint.copy(shader=shader, fill=None, somethingToDraw=True)
+
+    def radialGradient(self, startPoint, endPoint=None, colors=None, locations=None, startRadius=0, endRadius=100):
+        # MakeRadial(
+        #   center: skia.Point,
+        #   radius: float,
+        #   colors: List[int],
+        #   positions: object = None,
+        #   mode: skia.TileMode = TileMode.kClamp,
+        #   flags: int = 0,
+        #   localMatrix: skia.Matrix = None) → skia.Shader
+        if startRadius != 0:
+            logging.warning("radialGradient: startRadius != 0 ignored (it's not supported in drawbot-skia)")
+        if endPoint is not None and endPoint != startPoint:
+            logging.warning("radialGradient: endPoint argument ignored (it's not supported in drawbot-skia)")
+        colors = [_colorTupleToInt(_colorArgs(c)) for c in colors]
+        shader = skia.GradientShader.MakeRadial(
+            center=startPoint,
+            radius=endRadius,
+            colors=colors,
+            positions=locations,
+        )
+        self.fillPaint = self.fillPaint.copy(shader=shader, fill=None, somethingToDraw=True)
+
     # Text style
 
     def font(self, fontNameOrPath, fontSize=None):
@@ -158,6 +197,7 @@ class FillPaint(_ImmutableContainer):
     somethingToDraw = True
     color = (255, 0, 0, 0)  # ARGB
     blendMode = "normal"
+    shader = None
 
     @cached_property
     def skPaint(self):
@@ -171,6 +211,8 @@ class FillPaint(_ImmutableContainer):
         )
         paint.setARGB(*self.color)
         paint.setBlendMode(_blendModeMapping[self.blendMode])
+        if self.shader is not None:
+            paint.setShader(self.shader)
         return paint
 
 
@@ -373,6 +415,13 @@ def clearFontCache():
     _fontCache.clear()
 
 
+def _colorTupleToInt(color):
+    intColor = 0
+    for channel, shift in zip(color, (24, 16, 8, 0)):
+        intColor |= channel << shift
+    return intColor
+
+
 def _colorArgs(args):
     """Convert drawbot-style fill/stroke arguments to a tuple containing
     ARGB int values."""
